@@ -30,7 +30,7 @@ pub use view::View;
 pub use textfield::{TextField, FieldType};
 pub use picker::{Picker, PickerStyle, PickerOption};
 pub use icon::Icon;
-pub use image::Image;
+pub use image::{Image, ObjectFit};
 pub use popover::Popover;
 pub use hstack::HStack;
 pub use text::{Text, TextStyle};
